@@ -14,6 +14,7 @@ class DictionaryUpdateSequence:
     def regex(self):
         return r"dictionary update sequence element #0 has length 3; 2 is required"
 
+
 class DictionaryUpdateSequenceWithList:
     def title(self):
         return "Updating a dictionary with a list. "
@@ -40,18 +41,19 @@ class ClassMethodExists:
 
     def regex(self):
         return r"^class  \'(?P<class>([\w]*))\' has no attribute (?P<method>(\w+))"
+
+
 class ClassModelMethodExists:
     def title(self):
         return "Model method does not exist"
 
     def description(self):
-        return (
-            "Could not find the ':method' method on the model class. Please check spelling. If this is a method you expect to be on the builder class then check the ORM documentation"
-        )
+        return "Could not find the ':method' method on the model class. Please check spelling. If this is a method you expect to be on the builder class then check the ORM documentation"
 
     def regex(self):
         return r"^class model \'(?P<class>([\w]*))\' has no attribute (?P<method>(\w+))"
 
+
 class ImportIssueWithController:
     def title(self):
         return "Import Error In Controller"
@@ -65,26 +67,24 @@ class ImportIssueWithController:
     def regex(self):
         return r"named (?P<class>([\w]*)) has been found in"
 
+
 class IncorrectControllerName:
     def title(self):
         return "Mispelled Controller name"
 
     def description(self):
-        return (
-            "The :class controller could be mispelled. Check your routes file for :class and make sure that is the correct spelling."
-        )
+        return "The :class controller could be mispelled. Check your routes file for :class and make sure that is the correct spelling."
 
     def regex(self):
         return r"named (?P<class>([\w]*)) has been found in"
 
+
 class IncorrectlyDefinedRoute:
     def title(self):
         return "Check the controller and action is set correctly on the route."
 
     def description(self):
-        return (
-            "Check the definition on the controller is correct. If using string controllers it should be in the format of 'Controller@action'"
-        )
+        return "Check the definition on the controller is correct. If using string controllers it should be in the format of 'Controller@action'"
 
     def regex(self):
         return r"named (?P<class>([\w]*)) has been found in"
@@ -92,14 +92,13 @@ class IncorrectlyDefinedRoute:
     def documentation_link(self):
         return "https://docs.masoniteproject.com/the-basics/routing#creating-a-route"
 
+
 class RouteNameNotFound:
     def title(self):
         return "Check the the name exists in your routes file"
 
     def description(self):
-        return (
-            """Check the routes file and make sure there is a route with the ".name(':name')\" method. You can also run `python craft routes:list` to see a table of routes. Check for your named route in that table."""
-        )
+        return """Check the routes file and make sure there is a route with the ".name(':name')\" method. You can also run `python craft routes:list` to see a table of routes. Check for your named route in that table."""
 
     def regex(self):
         return r"Could not find route with the name \'(?P<name>([\w]*))\'"
@@ -107,6 +106,7 @@ class RouteNameNotFound:
     def documentation_link(self):
         return "https://docs.masoniteproject.com/the-basics/routing#name"
 
+
 class IncludedTemplateNotFound:
     def title(self):
         return "Check any imported templates inside the :name template."
@@ -119,16 +119,17 @@ class IncludedTemplateNotFound:
         )
 
     def regex(self):
-        return r"One of the included templates in the \'(?P<name>([\w]*))\' view could not be found"
+        return (
+            r"One of the included templates in the \'(?P<name>([\w]*))\' view could not be found"
+        )
+
 
 class UnexpectedEndBlock:
     def title(self):
         return "Check the :name was closed correctly."
 
     def description(self):
-        return (
-            "The error could be difficult to find so check ALL :name tags and make sure the :name tag is opened and closed correctly. "
-        )
+        return "The error could be difficult to find so check ALL :name tags and make sure the :name tag is opened and closed correctly. "
 
     def regex(self):
         return r"Unexpected end of template. Jinja was looking for the following tags: \'(?P<name>([\w]*))\'."
@@ -136,7 +137,7 @@ class UnexpectedEndBlock:
 
 class QueryDefaultValue:
     def title(self):
-        return "Missing default value for ':field'" 
+        return "Missing default value for ':field'"
 
     def description(self):
         return (
@@ -146,57 +147,66 @@ class QueryDefaultValue:
 
     def regex(self):
         return r"\(1364\, \"Field \'(?P<field>([\w]*))\' doesn't have a default value\"\)"
+
+
 class NoColumnExistsOnWhere:
     def title(self):
-        return "Check the table for the :field column" 
+        return "Check the table for the :field column"
 
     def description(self):
-        return (
-            "Could not find the :field column. Check your 'where' clauses. Is :field on the table you are trying to query? Did you run the migrations yet? Maybe it was not spelled correctly?"
-        )
+        return "Could not find the :field column. Check your 'where' clauses. Is :field on the table you are trying to query? Did you run the migrations yet? Maybe it was not spelled correctly?"
 
     def regex(self):
         return r"Unknown column \'(?P<field>([\w\.]*))\' in \'where clause\'"
 
+
 class NoColumnExistsOnWhereSQLite:
     def title(self):
-        return "Check the table for the :field column" 
+        return "Check the table for the :field column"
 
     def description(self):
-        return (
-            "Could not find the :field column. Is :field on the table you are trying to query? Did you run the migrations yet? Maybe it was not spelled correctly?"
-        )
+        return "Could not find the :field column. Is :field on the table you are trying to query? Did you run the migrations yet? Maybe it was not spelled correctly?"
 
     def regex(self):
         return r"no such column: (?P<field>([\w\.]*))"
 
+
 class NoColumnExistsOnSelect:
     def title(self):
-        return "Check the table for the :field column" 
+        return "Check the table for the :field column"
 
     def description(self):
-        return (
-            "Could not find the :field column. Check your 'select' clauses. Is :field on the table you are trying to query? Did you run the migrations yet? Maybe it was not spelled correctly?"
-        )
+        return "Could not find the :field column. Check your 'select' clauses. Is :field on the table you are trying to query? Did you run the migrations yet? Maybe it was not spelled correctly?"
 
     def regex(self):
         return r"Unknown column \'(?P<field>([\w\.]*))\' in \'field list\'"
 
+
 class UnsupportedOperand:
     def title(self):
-        return "Trying to do math for values that are not of the same type (:type1 and :type2)" 
+        return "Trying to do math for values that are not of the same type (:type1 and :type2)"
 
     def description(self):
-        return (
-            "Check the type of the 2 types. One is of type :type1 and the the other is of type :type2. They both need to be the same type"
-        )
+        return "Check the type of the 2 types. One is of type :type1 and the the other is of type :type2. They both need to be the same type"
 
     def regex(self):
         return r"unsupported operand type\(s\) for \+\: '(?P<type1>([\w\.]*))' and '(?P<type2>([\w\.]*))'"
 
+
+class DivisionByZeroError:
+    def title(self):
+        return "Check variables for any values that could be 0"
+
+    def description(self):
+        return "Check any place you are doing division. You cannot divide by a zero."
+
+    def regex(self):
+        return r"division by zero"
+
+
 class ContainerKeyNotFoundRegister:
     def title(self):
-        return "Did you register the key in the service provider or Kernel?" 
+        return "Did you register the key in the service provider or Kernel?"
 
     def description(self):
         return (
@@ -206,14 +216,13 @@ class ContainerKeyNotFoundRegister:
     def regex(self):
         return r"key was not found in the container"
 
+
 class ContainerKeyNotFoundServiceProvider:
     def title(self):
-        return "Did you register the service provider?" 
+        return "Did you register the service provider?"
 
     def description(self):
-        return (
-            "If you registered the key in your own service provider, did you register the provider in the config/providers.py file?"
-        )
+        return "If you registered the key in your own service provider, did you register the provider in the config/providers.py file?"
 
     def regex(self):
         return r"key was not found in the container"
@@ -221,26 +230,24 @@ class ContainerKeyNotFoundServiceProvider:
     def documentation_link(self):
         return "https://docs.masoniteproject.com/architecture/service-providers#registering-the-service-provider"
 
+
 class NotFound404:
     def title(self):
-        return "The '/:route' route could not be found" 
+        return "The '/:route' route could not be found"
 
     def description(self):
-        return (
-            "Could not find the '/:route' route. Try checking spelling is correct and the '/:route' is registered correctly in your routes files. You can also run 'python craft routes:list' to make sure the route shows up correctly"
-        )
+        return "Could not find the '/:route' route. Try checking spelling is correct and the '/:route' is registered correctly in your routes files. You can also run 'python craft routes:list' to make sure the route shows up correctly"
 
     def regex(self):
         return r"(?P<route>([\w]*)) \: 404 Not Found"
 
+
 class InvalidRouteMethodType:
     def title(self):
-        return "The method type is incorrect" 
+        return "The method type is incorrect"
 
     def description(self):
-        return (
-            "If this is a GET route, check if the route is actually defined as Route.post(). Or the opposite"
-        )
+        return "If this is a GET route, check if the route is actually defined as Route.post(). Or the opposite"
 
     def regex(self):
         return r"(?P<route>([\w]*)) \: 404 Not Found"
